@@ -46,7 +46,7 @@ K_PLUGIN_FACTORY(SKGBookmarkPluginFactory, registerPlugin<SKGBookmarkPlugin>();)
  */
 K_EXPORT_PLUGIN(SKGBookmarkPluginFactory("skg_bookmark", "skg_bookmark"))
 
-SKGBookmarkPlugin::SKGBookmarkPlugin(QObject* iParent, const QVariantList& iArg) :
+SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& iArg) :
     SKGInterfacePlugin(iParent), m_dockWidget(NULL)
 {
     Q_UNUSED(iArg);
@@ -80,8 +80,15 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_dockWidget->setWidget(new SKGBookmarkPluginDockWidget(m_currentDocument));
 
     // add action to control hide / display of Bookmarks
-    m_dockWidget->toggleViewAction()->setShortcut(Qt::SHIFT + Qt::Key_F10);
-    actionCollection()->addAction("view_bookmarks", m_dockWidget->toggleViewAction());
+    QAction* toggle = m_dockWidget->toggleViewAction();
+    KAction* panelAction = actionCollection()->addAction("view_bookmarks");
+    registerGlobalAction("view_bookmarks", panelAction);
+    panelAction->setCheckable(true);
+    panelAction->setChecked(toggle->isChecked());
+    panelAction->setText(toggle->text());
+    panelAction->setShortcut(Qt::SHIFT + Qt::Key_F10);
+    connect(panelAction, SIGNAL(triggered()), toggle, SLOT(trigger()));
+    connect(toggle, SIGNAL(toggled(bool)), panelAction, SLOT(setChecked(bool)));
 
     //Import bookmarks
     QStringList overlaybookmarks;
@@ -89,18 +96,16 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     m_importStdBookmarkAction = new KAction(KIcon("document-import", NULL, overlaybookmarks), i18nc("Verb", "Import standard bookmarks"), this);
     connect(m_importStdBookmarkAction, SIGNAL(triggered(bool)), SLOT(importStandardBookmarks()));
-    actionCollection()->addAction(QLatin1String("import_standard_bookmarks"), m_importStdBookmarkAction);
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("import_standard_bookmarks", m_importStdBookmarkAction);
+    registerGlobalAction("import_standard_bookmarks", m_importStdBookmarkAction);
 
     //
     KAction* goHome = KStandardAction::home(this, SLOT(goHome()), actionCollection());
     goHome->setPriority(QAction::LowPriority);
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("go_home", goHome);
+    registerGlobalAction("go_home", goHome);
 
     //Bookmark
     m_bookmarkAction = new KToolBarPopupAction(KIcon("bookmark-new-list"), i18nc("Verb, action to display bookmarks", "Bookmarks"), this);
-    connect(m_bookmarkAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(actionOpenBookmark()));
-    actionCollection()->addAction(QLatin1String("edit_bookmark"), m_bookmarkAction);
+    connect(m_bookmarkAction, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onOpenBookmark()));
     m_bookmarkMenu = static_cast<KMenu*>(m_bookmarkAction->menu());
     if (m_bookmarkMenu) {
         m_bookmarkMenu->setProperty("id", 0);
@@ -112,8 +117,8 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_bookmarkAction->setData(0);
     m_bookmarkAction->setPriority(QAction::LowPriority);
 
-    //bookmarkAction=KStandardAction::redo(this, SLOT(actionRedo()), actionCollection());
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit-bookmark", m_bookmarkAction);
+    //bookmarkAction=KStandardAction::redo(this, SLOT(onRedo()), actionCollection());
+    registerGlobalAction("edit_bookmark", m_bookmarkAction);
 
     return true;
 }
@@ -245,7 +250,7 @@ void SKGBookmarkPlugin::goHome()
     if (m_currentDocument) m_currentDocument->getObjects("v_node", "t_autostart='Y' ORDER BY f_sortorder, t_name", oNodeList);
     int nbAutoStartedBookmarks = oNodeList.count();
     for (int i = 0; i < nbAutoStartedBookmarks; ++i) {
-        SKGNodeObject autostarted_bookmark = oNodeList.at(i);
+        SKGNodeObject autostarted_bookmark(oNodeList.at(i));
         autostarted_bookmark.load();
         SKGTRACEIN(10, "autostarting bookmark : " % autostarted_bookmark.getName());
         SKGBookmarkPluginDockWidget::openBookmark(autostarted_bookmark, i > 0, true);
@@ -253,7 +258,7 @@ void SKGBookmarkPlugin::goHome()
     }
 }
 
-void SKGBookmarkPlugin::actionOpenBookmark(Qt::MouseButtons iMouse, Qt::KeyboardModifiers iKeyboard)
+void SKGBookmarkPlugin::onOpenBookmark(Qt::MouseButtons iMouse, Qt::KeyboardModifiers iKeyboard)
 {
     QAction* callerAction = qobject_cast<QAction*>(this->sender());
     if (callerAction) {
@@ -262,6 +267,31 @@ void SKGBookmarkPlugin::actionOpenBookmark(Qt::MouseButtons iMouse, Qt::Keyboard
     }
 }
 
+void SKGBookmarkPlugin::onAddBookmark()
+{
+    SKGTRACEIN(1, "SKGBookmarkPlugin::onAddBookmark");
+    SKGError err;
+
+    //Get current page
+    SKGNodeObject node;
+    {
+        //Get current selection
+        SKGNodeObject parentNode;
+        QAction* callerAction = qobject_cast<QAction*>(this->sender());
+        if (callerAction) {
+            parentNode = SKGNodeObject(m_currentDocument, callerAction->data().toInt());
+        }
+
+        //Create bookmark
+        err =  SKGBookmarkPluginDockWidget::createNodeFromPage(SKGMainPanel::getMainPanel()->currentPage(), parentNode, node);
+    }
+    //status bar
+    if (!err) {
+        err = SKGError(0, i18nc("Successful message after an user action", "Bookmark created"));
+    }
+    SKGMainPanel::displayErrorMessage(err);
+}
+
 void SKGBookmarkPlugin::onShowBookmarkMenu()
 {
     KMenu* callerMenu = qobject_cast<KMenu*>(this->sender());
@@ -279,7 +309,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
         m_currentDocument->getObjects("v_node", wc % " ORDER BY f_sortorder, t_name", listNode);
         int nb = listNode.count();
         for (int i = 0; i < nb; ++i) {
-            SKGNodeObject node = listNode.at(i);
+            SKGNodeObject node(listNode.at(i));
             if (node.isFolder()) {
                 //This is a folder
                 KMenu* menu = new KMenu(callerMenu);
@@ -298,7 +328,37 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
                     act->setText(node.getName());
                     act->setIcon(node.getIcon());
                     act->setData(node.getID());
-                    connect(act, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(actionOpenBookmark(Qt::MouseButtons,Qt::KeyboardModifiers)));
+                    connect(act, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onOpenBookmark(Qt::MouseButtons,Qt::KeyboardModifiers)));
+                }
+            }
+        }
+
+        //Add separator
+        QAction* sep = new QAction(this);
+        sep->setSeparator(true);
+        callerMenu->addAction(sep);
+
+        //This common actions
+        {
+            //Open all
+            KAction* act = new KAction(callerMenu);
+            if (act) {
+                callerMenu->addAction(act);
+                act->setText(i18nc("Action", "Open all"));
+                act->setIcon(KIcon("skg_open"));
+                act->setData(idParent);
+                connect(act, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onOpenBookmark(Qt::MouseButtons,Qt::KeyboardModifiers)));
+            }
+            if (SKGMainPanel::getMainPanel()->currentPageIndex() >= 0) {
+                //Bookmark current here
+                KAction* act = new KAction(callerMenu);
+                if (act) {
+                    callerMenu->addAction(act);
+                    act->setText(i18nc("Action", "Bookmark current page here"));
+                    act->setIcon(KIcon("list-add"));
+                    act->setData(idParent);
+
+                    connect(act, SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)), this, SLOT(onAddBookmark()));
                 }
             }
         }
