@@ -27,6 +27,7 @@
 #include "skgservices.h"
 #include "skgzoomselector.h"
 #include "skgflowlayout.h"
+#include "skgboardwidget.h"
 
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
@@ -41,7 +42,7 @@
 #define PLASMA (SKGServices::getenv("SKGPLASMA").isEmpty() ? false : true)
 
 SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
-    : SKGTabPage(iDocument), m_flowLayout(NULL), m_menu(NULL), m_addMenu(NULL), m_currentIndex(-1), m_plasmadashboard(NULL)
+    : SKGTabPage(iDocument), m_flowLayout(NULL), m_menu(NULL), m_addMenu(NULL), m_plasmadashboard(NULL)
 {
     SKGTRACEIN(1, "SKGDashboardPluginWidget::SKGDashboardPluginWidget");
     if (!iDocument) return;
@@ -88,52 +89,6 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
             ui.kTitle->setComment("<html><body><b>" % i18nc("Message", "Welcome to %1", about->programName()) % "</b></body></html>");
         }
 
-        //Floating panel
-        m_floatingPanel = new QWidget(this);
-        m_floatingPanel->resize(200, 24);
-        m_floatingPanel->setAutoFillBackground(true);
-        m_floatingPanel->setBackgroundRole(QPalette::AlternateBase);
-
-        QHBoxLayout* kHorizontalLayout = new QHBoxLayout(m_floatingPanel);
-        kHorizontalLayout->setObjectName(QString::fromUtf8("kDelete"));
-        kHorizontalLayout->setSpacing(0);
-        kHorizontalLayout->setContentsMargins(0, 0, 0, 0);
-        QToolButton* kDelete = new QToolButton(m_floatingPanel);
-        kDelete->setObjectName(QString::fromUtf8("kDelete"));
-        kDelete->setAutoRaise(true);
-        kDelete->setIcon(KIcon("edit-delete"));
-        kDelete->setToolTip(i18nc("Verb", "Remove"));
-        connect(kDelete, SIGNAL(clicked(bool)), this, SLOT(onRemoveWidget()));
-        kHorizontalLayout->addWidget(kDelete);
-
-        QToolButton* kMoveBefore = new QToolButton(m_floatingPanel);
-        kMoveBefore->setObjectName(QString::fromUtf8("kMoveBefore"));
-        kMoveBefore->setAutoRaise(true);
-        kMoveBefore->setIcon(KIcon("arrow-left"));
-        kMoveBefore->setToolTip(i18nc("Verb", "Move before"));
-        connect(kMoveBefore, SIGNAL(clicked(bool)), this, SLOT(onMoveBeforeWidget()));
-        kHorizontalLayout->addWidget(kMoveBefore);
-
-        QToolButton* kMoveAfter = new QToolButton(m_floatingPanel);
-        kMoveAfter->setObjectName(QString::fromUtf8("kMoveAfter"));
-        kMoveAfter->setAutoRaise(true);
-        kMoveAfter->setIcon(KIcon("arrow-right"));
-        kMoveAfter->setToolTip(i18nc("Verb", "Move after"));
-        connect(kMoveAfter, SIGNAL(clicked(bool)), this, SLOT(onMoveAfterWidget()));
-        kHorizontalLayout->addWidget(kMoveAfter);
-
-        m_kZoom = new SKGZoomSelector(m_floatingPanel);
-        m_kZoom->setObjectName(QString::fromUtf8("kZoom"));
-        m_kZoom->setResetValue(-10);
-        connect(m_kZoom, SIGNAL(changed(int)), this, SLOT(onZoomWidget(int)), Qt::QueuedConnection);
-
-        kHorizontalLayout->addWidget(m_kZoom);
-        m_floatingPanel->hide();
-
-        //Time to show floating panel
-        m_timer.setSingleShot(true);
-        connect(&m_timer, SIGNAL(timeout()), this, SLOT(onShowFloatingPanel()), Qt::QueuedConnection);
-
         //Build menu
         if (m_addMenu) {
             m_addMenu->clear();
@@ -159,8 +114,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
         }
 
         //Build layout
-        m_flowLayout = new SKGFlowLayout(ui.kContent);
-        m_flowLayout->setSpacing(0);
+        m_flowLayout = new SKGFlowLayout(ui.kContent, 0, 0, 0);
     }
 
     //Plug buttons with menus
@@ -175,8 +129,6 @@ SKGDashboardPluginWidget::~SKGDashboardPluginWidget()
     m_menu = NULL;
     m_addMenu = NULL;
     m_flowLayout = NULL;
-    m_floatingPanel = NULL;
-    m_kZoom = NULL;
     m_plasmadashboard = NULL;
 }
 
@@ -197,12 +149,12 @@ QString SKGDashboardPluginWidget::getState()
             root.appendChild(element);
 
             QStringList param = SKGServices::splitCSVLine(m_items.at(i), '-');
-            SKGWidget* item = m_itemsPointers.at(i);
+            SKGBoardWidget* item = m_itemsPointers.at(i);
             if (item) {
                 element.setAttribute("name", param.at(0));
                 element.setAttribute("index", param.at(1));
                 element.setAttribute("state", item->getState());
-                element.setAttribute("zoom", SKGServices::intToString(m_itemsSizes.at(i)));
+                element.setAttribute("zoom", SKGServices::intToString(item->getZoomRation() * 5 - 15));
             }
         }
     }
@@ -219,24 +171,20 @@ void SKGDashboardPluginWidget::setState(const QString& iState)
     if (PLASMA) {
     } else {
         //Initialisation
-        int nb = m_items.count();
-        for (int i = 0; m_flowLayout && i < nb; ++i) {
-            SKGWidget* item = m_itemsPointers.at(0);
+        int nb = (m_flowLayout ? m_flowLayout->count() : 0);
+        for (int i = 0; i < nb; ++i) {
+            SKGBoardWidget* item = m_itemsPointers.at(0);
             if (item) {
                 m_flowLayout->removeWidget(item);
                 item->hide();
 
                 m_items.removeAt(0);
                 m_itemsPointers.removeAt(0);
-                m_itemsSizes.removeAt(0);
 
-                delete item;
+                item->deleteLater();
             }
         }
 
-        m_currentIndex = -1;
-        m_floatingPanel->hide();
-
         QString zoomPositionS = root.attribute("zoomPosition");
         if (zoomPositionS.isEmpty()) zoomPositionS = '0';
         setZoomPosition(SKGServices::stringToInt(zoomPositionS));
@@ -307,32 +255,19 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
                  event->type() == QEvent::Drop ||
                  event->type() == QEvent::HoverMove
                 )) {
-            //Search SKGWidget corresponding to this widget
-            SKGWidget* toMove = NULL;
+            //Search SKGBoardWidget corresponding to this widget
+            SKGBoardWidget* toMove = NULL;
             int toMoveIndex = -1;
             int nb = m_itemsPointers.count();
             for (int i = 0; toMove == NULL && i < nb; ++i) {
-                SKGWidget* w = m_itemsPointers.at(i);
+                SKGBoardWidget* w = m_itemsPointers.at(i);
                 if (w && w->getDragWidget() == object) {
                     toMove = w;
                     toMoveIndex = i;
                 }
             }
 
-            if (event->type() == QEvent::HoverMove) {
-                //Move floating panel and start waiting time
-                QHoverEvent* mevent = (QHoverEvent*) event;
-                m_floatingPanel->hide();
-                if (m_clickedPoint == QPoint(-1, -1) && mevent->pos().y() <= 20) {
-                    m_timer.start(500);
-
-                    //Memorize information
-                    m_currentIndex = toMoveIndex;
-                    m_lastPoint = mevent->pos();
-                }
-
-                return true;
-            } else if (event->type() == QEvent::MouseButtonPress) {
+            if (event->type() == QEvent::MouseButtonPress) {
                 //Drag
                 QMouseEvent* mevent = (QMouseEvent*) event;
                 if (mevent->button() == Qt::LeftButton) {
@@ -389,17 +324,7 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* object, QEvent* event)
 
                     //Move item
                     if (toMoveIndex > oldPos) --toMoveIndex;
-                    m_items.move(oldPos, toMoveIndex);
-                    m_itemsPointers.move(oldPos, toMoveIndex);
-                    m_itemsSizes.move(oldPos, toMoveIndex);
-
-                    //Get new state
-                    QString state = getState();
-
-                    //Reset state
-                    setState(state);
-
-                    m_clickedPoint = QPoint(-1, -1);
+                    moveItem(oldPos, toMoveIndex);
 
                     return true;
                 }
@@ -415,25 +340,6 @@ void SKGDashboardPluginWidget::showHeaderMenu(const QPoint& pos)
     if (m_menu) m_menu->popup(mapToGlobal(pos));
 }
 
-void SKGDashboardPluginWidget::onShowFloatingPanel()
-{
-    QRect rc = m_floatingPanel->geometry();
-    rc.moveCenter(this->mapFromGlobal((m_itemsPointers[m_currentIndex]->mapToGlobal(m_lastPoint))));
-    m_floatingPanel->setGeometry(rc);
-
-    if (m_kZoom) {
-        QSize size = m_itemsPointers[m_currentIndex]->minimumSize();
-        if (size.height() && size.width()) {
-            m_kZoom->setEnabled(true);
-            m_kZoom->setValue(m_itemsSizes[m_currentIndex] - 10, false);
-        } else {
-            m_kZoom->setEnabled(false);
-        }
-    }
-
-    m_floatingPanel->show();
-}
-
 void SKGDashboardPluginWidget::onAddWidget()
 {
     QAction* sender = qobject_cast<QAction*>(this->sender());
@@ -442,168 +348,89 @@ void SKGDashboardPluginWidget::onAddWidget()
         QStringList param = SKGServices::splitCSVLine(id, '-');
 
         SKGInterfacePlugin* db = SKGMainPanel::getMainPanel()->getPluginByName(param.at(0));
-        if (db) {
-            SKGWidget* dbw = db->getDashboardWidget(SKGServices::stringToInt(param.at(1)));
-            if (dbw) {
-                //Add
-                m_items.push_back(id);
-                m_itemsPointers.push_back(dbw);
-                m_itemsSizes.push_back(0);
+        if (db) addItem(db, SKGServices::stringToInt(param.at(1)));
+    }
+}
 
-                //Get new state
-                QString state = getState();
+void SKGDashboardPluginWidget::onMoveWidget(int iMove)
+{
+    //Get current position
+    int pos = -1;
+    QWidget* sender = qobject_cast<QWidget*>(this->sender());
+    if (sender) {
+        pos = m_itemsPointers.indexOf(parentBoardWidget(sender));
+        int newPos = pos + iMove;
+        if (newPos < 0) newPos = 0;
+        else if (newPos > m_items.count() - 1) newPos = m_items.count() - 1;
 
-                //Remove added item
-                m_items.pop_back();
-                m_itemsPointers.pop_back();
-                m_itemsSizes.pop_back();
+        moveItem(pos, newPos);
+    }
+}
 
-                //Reset state
-                setState(state);
-            }
+void SKGDashboardPluginWidget::moveItem(int iFrom, int iTo)
+{
+    //Compute new position
+    if (iTo != iFrom) {
+        //Move item
+        m_items.move(iFrom, iTo);
+        m_itemsPointers.move(iFrom, iTo);
+
+        //Build list of items in the right order
+        QList<SKGBoardWidget*> listWidgets;
+        int nb = m_itemsPointers.count();
+        for (int i = 0; i < nb; ++i) {
+            SKGBoardWidget* wgt2 = m_itemsPointers.at(i);
+            m_flowLayout->removeWidget(wgt2);
+            listWidgets.push_back(wgt2);
         }
+
+        //Add items
+        nb = listWidgets.count();
+        for (int i = 0; i < nb; ++i) {
+            SKGBoardWidget* dbw = listWidgets.at(i);
+            dbw->setParent(ui.kContent);
+            m_flowLayout->addWidget(dbw);
+        }
+
+
     }
 }
 
-void SKGDashboardPluginWidget::onMoveAfterWidget()
+SKGBoardWidget* SKGDashboardPluginWidget::parentBoardWidget(QWidget* iWidget)
 {
-    int pos = m_currentIndex;
-    QAction* sender = qobject_cast<QAction*>(this->sender());
-    if (sender) pos = sender->data().toInt();
-
-    if (pos >= 0 && pos < m_items.count() - 1) { //last one cannot be moved after
-        //Move item
-        m_items.move(pos, pos + 1);
-        m_itemsPointers.move(pos, pos + 1);
-        m_itemsSizes.move(pos, pos + 1);
-
-        //Get new state
-        QString state = getState();
-
-        //Reset state
-        setState(state);
+    SKGBoardWidget* output = qobject_cast< SKGBoardWidget* >(iWidget);
+    if (!output && iWidget) {
+        QWidget* parent = iWidget->parentWidget();
+        if (parent)  output = SKGDashboardPluginWidget::parentBoardWidget(parent);
     }
-}
 
-void SKGDashboardPluginWidget::onMoveBeforeWidget()
-{
-    int pos = m_currentIndex;
-    QAction* sender = qobject_cast<QAction*>(this->sender());
-    if (sender) pos = sender->data().toInt();
-
-    if (pos > 0 && pos <= m_items.count() - 1) { //first one cannot be moved before
-        //Move item
-        m_items.move(pos, pos - 1);
-        m_itemsPointers.move(pos, pos - 1);
-        m_itemsSizes.move(pos, pos - 1);
-
-        //Get new state
-        QString state = getState();
-
-        //Reset state
-        setState(state);
-    }
+    return output;
 }
 
 void SKGDashboardPluginWidget::onRemoveWidget()
 {
-    int pos = m_currentIndex;
-    QAction* sender = qobject_cast<QAction*>(this->sender());
-    if (sender) pos = sender->data().toInt();
-
+    int pos = -1;
+    QWidget* sender = qobject_cast<QWidget*>(this->sender());
+    if (sender) pos = m_itemsPointers.indexOf(parentBoardWidget(sender));
     if (pos >= 0) {
         //Get item
-        QString id = m_items.at(pos);
-        SKGWidget* wgt = m_itemsPointers.at(pos);
-        int s = m_itemsSizes.at(pos);
+        SKGBoardWidget* wgt = m_itemsPointers.at(pos);
+
+        //Delete widget
+        m_flowLayout->removeWidget(wgt);
+        wgt->hide();
+        wgt->deleteLater();
 
         //Remove item
         m_items.removeAt(pos);
         m_itemsPointers.removeAt(pos);
-        m_itemsSizes.removeAt(pos);
-
-        //Get new state
-        QString state = getState();
-
-        //We add removed object to be sure that it will be removed
-        m_items.push_back(id);
-        m_itemsPointers.push_back(wgt);
-        m_itemsSizes.push_back(s);
-
-        //Reset state
-        setState(state);
-    }
-}
-void SKGDashboardPluginWidget::onZoomWidget(int iValue)
-{
-    int pos = m_currentIndex;
-    if (pos >= 0) {
-        //Remove item
-        m_itemsSizes.removeAt(pos);
-
-        //Add it after
-        m_itemsSizes.insert(pos, iValue + 10);
-
-        //Get new state
-        QString state = getState();
-
-        //Reset state
-        setState(state);
-    }
-}
-
-void SKGDashboardPluginWidget::onZoomInWidget()
-{
-    QAction* sender = qobject_cast<QAction*>(this->sender());
-    if (sender) {
-        int pos = sender->data().toInt();
-        if (pos >= 0) {
-            //Get item
-            int s = m_itemsSizes.at(pos);
-
-            //Remove item
-            m_itemsSizes.removeAt(pos);
-
-            //Add it after
-            m_itemsSizes.insert(pos, qMin(s + 1, 20));
-
-            //Get new state
-            QString state = getState();
-
-            //Reset state
-            setState(state);
-        }
-    }
-}
-
-void SKGDashboardPluginWidget::onZoomOutWidget()
-{
-    QAction* sender = qobject_cast<QAction*>(this->sender());
-    if (sender) {
-        int pos = sender->data().toInt();
-        if (pos >= 0) {
-            //Get item
-            int s = m_itemsSizes.at(pos);
-
-            //Remove item
-            m_itemsSizes.removeAt(pos);
-
-            //Add it after
-            m_itemsSizes.insert(pos, qMax(s - 1, 0));
-
-            //Get new state
-            QString state = getState();
-
-            //Reset state
-            setState(state);
-        }
     }
 }
 
 void SKGDashboardPluginWidget::addItem(SKGInterfacePlugin* iDashboard, int iIndex, int iZoom, const QString& iState)
 {
     if (iDashboard && m_flowLayout) {
-        SKGWidget* dbw = iDashboard->getDashboardWidget(iIndex);
+        SKGBoardWidget* dbw = iDashboard->getDashboardWidget(iIndex);
         if (dbw) {
             //Add widget
             dbw->setParent(ui.kContent);
@@ -618,17 +445,16 @@ void SKGDashboardPluginWidget::addItem(SKGInterfacePlugin* iDashboard, int iInde
                 drag->setAttribute(Qt::WA_Hover);
             }
 
+            //Connect widget
+            connect(dbw, SIGNAL(requestRemove()), this, SLOT(onRemoveWidget()), Qt::QueuedConnection);
+            connect(dbw, SIGNAL(requestMove(int)), this, SLOT(onMoveWidget(int)), Qt::QueuedConnection);
+
             //Set size
-            QSize size = dbw->minimumSize();
-            //double ratio=pow(10.0,((qreal) iZoom+1)/20.0);
-            double ratio = ((double)iZoom) / 5.0 + 1.0;
-            QSize newSize(size.width()*ratio, size.height()*ratio);
-            dbw->setMinimumSize(newSize);
+            dbw->setZoomRation((iZoom + 15.0) / 5.0);
 
             QString id = iDashboard->objectName() % '-' % SKGServices::intToString(iIndex);
             m_items.push_back(id);
             m_itemsPointers.push_back(dbw);
-            m_itemsSizes.push_back(iZoom);
         }
     }
 }
