@@ -33,6 +33,7 @@ class KMenu;
 class SKGInterfacePlugin;
 class SKGZoomSelector;
 class SKGFlowLayout;
+class SKGBoardWidget;
 namespace
 {
 class KPartsPart;
@@ -111,33 +112,26 @@ private Q_SLOTS:
     void showHeaderMenu(const QPoint& pos);
     void onAddWidget();
     void onRemoveWidget();
-    void onZoomWidget(int iValue);
-    void onMoveAfterWidget();
-    void onMoveBeforeWidget();
-    void onZoomInWidget();
-    void onZoomOutWidget();
-    void onShowFloatingPanel();
+    void onMoveWidget(int iMove);
 
 private:
-    Q_DISABLE_COPY(SKGDashboardPluginWidget);
+    Q_DISABLE_COPY(SKGDashboardPluginWidget)
 
-    void addItem(SKGInterfacePlugin* iDashboard, int iIndex, int iZoom = 0, const QString& iState = "");
+    void addItem(SKGInterfacePlugin* iDashboard, int iIndex, int iZoom = -10, const QString& iState = "");
+    void moveItem(int iFrom, int iTo);
+    static SKGBoardWidget* parentBoardWidget(QWidget* iWidget);
 
     Ui::skgdashboardplugin_base ui;
     SKGFlowLayout* m_flowLayout;
 
     QStringList m_items;
-    QList<SKGWidget*> m_itemsPointers;
-    QList<int> m_itemsSizes;
+    QList<SKGBoardWidget*> m_itemsPointers;
     KMenu* m_menu;
     QMenu* m_addMenu;
-    QWidget* m_floatingPanel;
-    SKGZoomSelector* m_kZoom;
     QTimer m_timer;
 
     QPoint m_clickedPoint;
     QPoint m_lastPoint;
-    int m_currentIndex;
     KParts::Part* m_plasmadashboard;
 };
 
