@@ -28,7 +28,6 @@
 #include <kstandarddirs.h>
 #include <knewstuff3/downloaddialog.h>
 #include <knewstuff3/uploaddialog.h>
-#include <kio/netaccess.h>
 #include <kmenu.h>
 #include <kzip.h>
 #include <kcomponentdata.h>
@@ -156,7 +155,7 @@ void SKGMonthlyPluginWidget::onAddTemplate()
         if (!templates.contains(templatFileName)) {
             //Create the new template
             QString source = KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default.txt");
-            if (!KIO::NetAccess::file_copy(source, templatFileName)) {
+            if (SKGServices::upload(source, templatFileName)) {
                 //Set error message
                 err.setReturnCode(ERR_FAIL);
                 err.setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
@@ -213,6 +212,7 @@ void SKGMonthlyPluginWidget::dataModified(const QString& iTableName, int iIdTran
 
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
+    //TODO: v_operation_display must be generic
     if (db != NULL && (iTableName == "v_operation_display" || iTableName.isEmpty())) {
         //Fill combo
         disconnect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()));
