@@ -89,7 +89,7 @@ private Q_SLOTS:
     QString getReport();
 
 private:
-    Q_DISABLE_COPY(SKGMonthlyPluginWidget);
+    Q_DISABLE_COPY(SKGMonthlyPluginWidget)
     void fillTemplateList();
 
     Ui::skgmonthlyplugin_base ui;
