@@ -35,13 +35,13 @@ class QDockWidget;
 class SKGPropertiesPlugin : public SKGInterfacePlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGInterfacePlugin);
+    Q_INTERFACES(SKGInterfacePlugin)
 
 public:
     /**
      * Default Constructor
      */
-    explicit SKGPropertiesPlugin(QObject* iParent, const QVariantList& iArg);
+    explicit SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -86,11 +86,11 @@ public:
     virtual int getOrder() const;
 
 private Q_SLOTS:
-    void actionAddProperty();
+    void onAddProperty();
     void onShowAddPropertyMenu();
 
 private:
-    Q_DISABLE_COPY(SKGPropertiesPlugin);
+    Q_DISABLE_COPY(SKGPropertiesPlugin)
 
     SKGDocument* m_currentDocument;
     QDockWidget* m_dockWidget;
