@@ -56,7 +56,7 @@ SKGImportPluginGsb::~SKGImportPluginGsb()
 bool SKGImportPluginGsb::isImportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "GSB");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "GSB");
 }
 
 SKGError SKGImportPluginGsb::importFile()
@@ -70,7 +70,7 @@ SKGError SKGImportPluginGsb::importFile()
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
     if (!file->open(QIODevice::ReadOnly)) {
         err.setReturnCode(ERR_INVALIDARG);
-        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName()));
+        err.setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
     } else {
         QDomDocument doc;
 
@@ -98,7 +98,7 @@ SKGError SKGImportPluginGsb::importFile()
         }
 
         if (!contentOK) {
-            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName()));
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
         } else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GSB"), 9);
 
@@ -332,7 +332,7 @@ SKGError SKGImportPluginGsb::importFile()
 
                     mapIdOperation[getAttribute(transaction,  "Nb")] = opObj;
 
-                    if (!err && i % 100 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
@@ -447,7 +447,7 @@ SKGError SKGImportPluginGsb::importFile()
                     }
                     if (!err) err = recuObj.save();
 
-                    if (!err && i % 100 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
                     if (!err) err = m_importer->getDocument()->stepForward(i + 1);
                 }
 
