@@ -120,7 +120,7 @@ SKGError SKGImportPluginKmy::importFile()
                     SKGUnitObject unitObj(m_importer->getDocument());
                     SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), unitName, unitObj);
 
-                    if (!err && !unitObj.exist()) {
+                    if (!err && !unitObj.getID()) {
                         //Creation of unit
                         err = unitObj.setName(unitName);
                         QString symbol = security.attribute("symbol");
@@ -161,7 +161,7 @@ SKGError SKGImportPluginKmy::importFile()
                     QDomElement pricepair = pricepairList.at(i).toElement();
 
                     SKGUnitObject unitObj = m_mapIdUnit[pricepair.attribute("from")];
-                    if (unitObj.exist()) {
+                    if (unitObj.getID()) {
                         //Unit is existing
                         QDomNodeList pricesList = pricepair.elementsByTagName("PRICE");
                         int nb2 = pricesList.count();
@@ -267,7 +267,7 @@ SKGError SKGImportPluginKmy::importFile()
                     } else if (type != "16") {
                         //Create category
                         SKGCategoryObject cat = m_mapIdCategory[account.attribute("id")];
-                        if (cat.exist()) {
+                        if (cat.getID()) {
                             //Already existing ==> we must set the right name
                             err = cat.setName(account.attribute("name"));
                             if (!err) err = cat.save();
@@ -288,10 +288,10 @@ SKGError SKGImportPluginKmy::importFile()
 
                             //Is child already existing ?
                             SKGCategoryObject cat2 = m_mapIdCategory[subaccount.attribute("id")];
-                            if (cat2.exist()) {
+                            if (cat2.getID()) {
                                 //Yes ==> reparent
                                 err = cat2.setParentCategory(cat);
-                                if (!err) err = cat2.save();
+                                if (!err) err = cat2.save(true, false);
                             } else {
                                 //No ==> create
                                 if (!err) err = cat.addCategory(cat2);
@@ -409,7 +409,7 @@ SKGError SKGImportPluginKmy::importFile()
                                 }
                             }
 
-                            if (!err) err = recuObj.save();
+                            if (!err) err = recuObj.save(true, false);
                         }
                     }
 
@@ -450,7 +450,6 @@ SKGError SKGImportPluginKmy::importFile()
                         }
                         if (!err) err = operationObj.save();
 
-
                         if (m_mapIdCategory.contains(suboperation.attribute("account"))) {
                             //It is a split on category
                             SKGCategoryObject cat = m_mapIdCategory[suboperation.attribute("account")];
@@ -460,16 +459,16 @@ SKGError SKGImportPluginKmy::importFile()
                             if (vals.count() == 1) q = -SKGServices::stringToDouble(vals.at(0));
                             else if (vals.count() == 2) q = -SKGServices::stringToDouble(vals.at(0)) / SKGServices::stringToDouble(vals.at(1));
 
-                            if (!err && (!suboperationObj.exist() || suboperationObj.getQuantity() != q)) err = operationObj.addSubOperation(suboperationObj);
+                            if (!err && (!suboperationObj.getID() || suboperationObj.getQuantity() != q)) err = operationObj.addSubOperation(suboperationObj);
                             if (!err) err = suboperationObj.setQuantity(q);
                             if (!err) err = suboperationObj.setCategory(cat);
                             if (!err) err = suboperationObj.setComment(suboperation.attribute("memo"));
-                            if (!err) err = suboperationObj.save();
+                            if (!err) err = suboperationObj.save(true, false);
                         } else if (!m_mapIdAccount.contains(suboperation.attribute("account"))) {
                             //Set as initial balance
                             if (!err) err = operationObj.setAttribute("d_date", "0000-00-00");
                             if (!err) err = operationObj.setStatus(SKGOperationObject::CHECKED);
-                            if (!err) err = operationObj.save();
+                            if (!err) err = operationObj.save(true, false);
                         } else {
                             //It is a transfer of account
                             SKGAccountObject act = m_mapIdAccount[suboperation.attribute("account")];
@@ -515,7 +514,7 @@ SKGError SKGImportPluginKmy::importFile()
                                     err = suboperationObj2.setQuantity(quantity);
                                 }
                                 if (!err) err = suboperationObj2.setComment(suboperation.attribute("memo"));
-                                if (!err) err = suboperationObj2.save();
+                                if (!err) err = suboperationObj2.save(true, false);
                             } else {
                                 //We set the parent
                                 act.setClosed(false); //To be sure that the modification is possible. NOT SAVED
@@ -533,7 +532,7 @@ SKGError SKGImportPluginKmy::importFile()
                                     if (!err) err = operationObj.addSubOperation(suboperationObj);
                                     if (!err) err = suboperationObj.setQuantity(quantity);
                                     if (!err) err = suboperationObj.setComment(suboperation.attribute("memo"));
-                                    if (!err) err = suboperationObj.save();
+                                    if (!err) err = suboperationObj.save(true, false);
                                 }
 
                                 parentSet = true;
@@ -601,7 +600,7 @@ SKGError SKGImportPluginKmy::importFile()
                                     if (!err) err = budget.setYear(SKGServices::stringToDouble(dates.at(0)));
                                     if (!err) err = budget.setMonth(budgetlevel == "monthbymonth" ? SKGServices::stringToDouble(dates.at(1)) :
                                                                         budgetlevel == "yearly" ? 0 : m);
-                                    if (!err) err = budget.save();
+                                    if (!err) err = budget.save(true, false);
                                 }
                             }
                         }
@@ -997,7 +996,7 @@ SKGError SKGImportPluginKmy::exportFile()
                         SKGCategoryObject parent;
                         obj.getParentCategory(parent);
 
-                        QString parentId = (parent.exist() ? parent.getUniqueID() : (obj.getCurrentAmount() < 0 ? "AStd::Expense" : "AStd::Income"));
+                        QString parentId = (parent.getID() ? parent.getUniqueID() : (obj.getCurrentAmount() < 0 ? "AStd::Expense" : "AStd::Income"));
                         if (parentId == "AStd::Expense") {
                             QDomElement subaccount = doc.createElement("SUBACCOUNT");
                             accountExpense.appendChild(subaccount);
@@ -1361,7 +1360,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
 
         SKGPayeeObject payeeObject;
         iOperation.getPayee(payeeObject);
-        QString payeeId = (payeeObject.exist() ? payeeObject.getUniqueID() : "");
+        QString payeeId = (payeeObject.getID() ? payeeObject.getUniqueID() : "");
 
         //Split for account
         split.setAttribute("payee", payeeId);
@@ -1427,7 +1426,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
                 split.setAttribute("reconcileflag", reconcileflag);
                 split.setAttribute("memo", subop.getComment());
                 split.setAttribute("value", shape);
-                split.setAttribute("account", date == "0000-00-00" ? "AStd::Equity" : (cat.exist() ? cat.getUniqueID() : ""));
+                split.setAttribute("account", date == "0000-00-00" ? "AStd::Equity" : (cat.getID() ? cat.getUniqueID() : ""));
             }
         }
 
