@@ -29,7 +29,7 @@
 class SKGImportPluginMmb : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -64,7 +64,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginMmb);
+    Q_DISABLE_COPY(SKGImportPluginMmb)
 };
 
 #endif // SKGIMPORTPLUGINMMB_H
