@@ -31,7 +31,7 @@ class SKGObjectBase;
 class SKGImportPluginSkg : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -80,7 +80,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginSkg);
+    Q_DISABLE_COPY(SKGImportPluginSkg)
 
     static SKGError copyParameters(const SKGObjectBase& iFrom, const SKGObjectBase& iTo);
 };
