@@ -240,7 +240,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                     //Build display
                     SKGStringListList listTmp;
                     err = doc->executeSelectSqliteOrder(
-                              QString("SELECT t_name, t_TYPENLS, ") % (m_menuPastOperations && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
+                              QString("SELECT t_name, t_TYPENLS, t_UNIT, ") % (m_menuPastOperations && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
                               listTmp);
                     if (!err) {
                         html += "<html><body><table>";
@@ -252,8 +252,9 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                             QStringList r = listTmp.at(i);
                             QString name = r.at(0);
                             QString type = r.at(1);
-                            double v1 = SKGServices::stringToDouble(r.at(2));
-                            bool closed = (r.at(3) == "Y");
+                            QString unitAccountSymbol = r.at(2);
+                            double v1 = SKGServices::stringToDouble(r.at(3));
+                            bool closed = (r.at(4) == "Y");
 
                             if (type != currentType) {
                                 if (!currentType.isEmpty()) {
@@ -264,18 +265,14 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                 currentType = type;
                             }
                             if (!closed || qAbs(v1) > 0.1) {
-                                SKGAccountObject account(getDocument());
-                                account.setName(name);
-                                account.load();
-
-                                SKGUnitObject unitAccount;
-                                account.getUnit(unitAccount);
-                                QString unitAccountSymbol = unitAccount.getSymbol();
-
                                 html += QString("<tr><td><a href=\"skg://Skrooge_operation_plugin/?account=" % SKGServices::encodeForUrl(name) % "\">") % SKGServices::stringToHtml(name) % "</a></td>"
                                         "<td align=\"right\">";
 
                                 if (!unitAccountSymbol.isEmpty() && primary.Symbol != unitAccountSymbol) {
+                                    SKGUnitObject unitAccount(getDocument());
+                                    unitAccount.setSymbol(unitAccountSymbol);
+                                    unitAccount.load();
+
                                     double unitAccountValue = SKGServices::stringToDouble(unitAccount.getAttribute("f_CURRENTAMOUNT"));
                                     SKGServices::SKGUnitInfo u2 = primary;
                                     u2.Symbol = unitAccountSymbol;
