@@ -40,6 +40,7 @@
 
 #include <QTextCodec>
 #include <QDomDocument>
+#include <kmessagewidget.h>
 /**
  * This plugin factory.
  */
@@ -49,7 +50,7 @@ K_PLUGIN_FACTORY(SKGImportExportPluginFactory, registerPlugin<SKGImportExportPlu
  */
 K_EXPORT_PLUGIN(SKGImportExportPluginFactory("skrooge_importexport", "skrooge_importexport"))
 
-SKGImportExportPlugin::SKGImportExportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
+SKGImportExportPlugin::SKGImportExportPlugin(QWidget* /*iWidget*/, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_install(false)
 {
     SKGTRACEIN(10, "SKGImportExportPlugin::SKGImportExportPlugin");
 }
@@ -194,7 +195,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
 
     //Krunner operations
     QString dirName = QDir::homePath() % "/.skrooge/";
-    QStringList fileList = QDir(dirName).entryList(QDir::Files);
+    QStringList fileList = QDir(dirName).entryList(QStringList() << "add_operation_*.txt", QDir::Files);
     if (fileList.count()) m_currentBankDocument->sendMessage(i18nc("Information message", "You have some krunner's operations to import"));
 
     return true;
@@ -307,10 +308,40 @@ void SKGImportExportPlugin::refresh()
             if (m_validateImportedOperationsAction) m_validateImportedOperationsAction->setEnabled(false);
             if (m_mergeImportedOperationAction) m_mergeImportedOperationAction->setEnabled(false);
         }
+
+        //Automatic download
+        if (test) {
+            QString doc_id = m_currentBankDocument->getUniqueIdentifier();
+            if (m_docUniqueIdentifier != doc_id) {
+                m_docUniqueIdentifier = doc_id;
+
+                SKGError err;
+
+                if (skgimportexport_settings::download_on_open()) {
+                    //Check frequency
+                    QString lastAutomaticDownload = m_currentBankDocument->getParameter("SKG_LAST_BACKEND_AUTOMATIC_DOWNLOAD");
+                    if (!lastAutomaticDownload.isEmpty()) {
+                        //The automatic import is not done if at least one manual import has not been done
+                        QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, "yyyy-MM-dd");
+                        if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgimportexport_settings::download_frequency() == 0) ||
+                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgimportexport_settings::download_frequency() == 1) ||
+                                (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgimportexport_settings::download_frequency() == 2))
+
+                        {
+                            //Import
+                            err = importbackends();
+                        }
+
+                        //Display error
+                        SKGMainPanel::displayErrorMessage(err);
+                    }
+                }
+            }
+        }
     }
 }
 
-void SKGImportExportPlugin::importbackends()
+SKGError SKGImportExportPlugin::importbackends()
 {
     SKGError err;
     SKGTRACEINRC(10, "SKGImportExportPlugin::importbackends", err);
@@ -353,6 +384,9 @@ void SKGImportExportPlugin::importbackends()
             if (!err) err = imp1.importFile();
             if (!err) err = m_currentBankDocument->stepForward(i + 1);
         }
+
+        //Memorize the last download date
+        if (!err) err = m_currentBankDocument->setParameter("SKG_LAST_BACKEND_AUTOMATIC_DOWNLOAD", QDate::currentDate().toString("yyyy-MM-dd"));
     }
 
     //Display error
@@ -360,6 +394,8 @@ void SKGImportExportPlugin::importbackends()
 
     //Open last modified operations if setting activated
     if (!err) openLastModifiedIfSetting();
+
+    return err;
 }
 
 void SKGImportExportPlugin::import(const QString& iFile)
@@ -443,18 +479,31 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         parameters["columns_positions"] = skgimportexport_settings::columns_positions();
                         parameters["mode_csv_unit"] = (sender() == m_importCsvUnitAction ? "Y" : "N");
                         parameters["date_format"] = skgimportexport_settings::csv_date_format();
-                        if (parameters["date_format"] == i18nc("Format date", "Automatic detection")) parameters["date_format"] = "";
+                        if (!parameters["date_format"].contains("YY")) parameters["date_format"] = "";
 
                         imp1.setImportParameters(parameters);
                     } else if (QFileInfo(fileName.path()).suffix().toUpper() == "QIF") { //TODO: Better
                         QMap<QString, QString> parameters = imp1.getImportParameters();
 
                         parameters["date_format"] = skgimportexport_settings::qif_date_format();
-                        if (parameters["date_format"] == i18nc("Format date", "Automatic detection")) parameters["date_format"] = "";
+                        if (!parameters["date_format"].contains("YY")) parameters["date_format"] = "";
 
                         imp1.setImportParameters(parameters);
                     }
 
+                    //Optimization
+                    if (i != nbFiles - 1) {
+                        QMap< QString, QString > parameters = imp1.getImportParameters();
+                        parameters["donotfinalize"] = 'Y';
+                        imp1.setImportParameters(parameters);
+                    }
+
+                    if (m_install) {
+                        QMap< QString, QString > parameters = imp1.getImportParameters();
+                        parameters["install"] = 'Y';
+                        imp1.setImportParameters(parameters);
+                    }
+
                     if (!err) err = imp1.importFile();
                     if (err && err.getReturnCode() == ERR_ENCRYPTION) {
                         QString pwd;
@@ -493,7 +542,7 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
                         } while (err);
                     }
 
-                    if (err) {
+                    if (err && err.getReturnCode() != ERR_INSTALL) {
                         err.addError(ERR_FAIL, i18nc("Error message", "Import of file named '%1' failed", fileName.prettyUrl()));
                     }
 
@@ -508,13 +557,28 @@ void SKGImportExportPlugin::import(const QList<KUrl>& iFiles)
         }
 
         //Display error
-        SKGMainPanel::displayErrorMessage(err);
+        m_install = false;
+        KMessageWidget* msg = SKGMainPanel::displayErrorMessage(err);
+        if (err.getReturnCode() == ERR_INSTALL && msg) {
+            QString application = err.property("application").toString();
+            QAction* install = new QAction(i18nc("Noun", "Install %1", application), msg);
+            install->setIcon(KIcon("download"));
+            msg->addAction(install);
+            connect(install, SIGNAL(triggered(bool)), this, SLOT(onInstall()));
+            connect(install, SIGNAL(triggered(bool)), msg, SLOT(deleteLater()), Qt::QueuedConnection);
+        }
 
         //Open last modified operations if setting activated
         if (!err) openLastModifiedIfSetting();
     }
 }
 
+void SKGImportExportPlugin::onInstall()
+{
+    m_install = true;
+    SKGMainPanel::getMainPanel()->displayMessage(i18nc("Information message", "The installation will be done during the next import"));
+}
+
 void SKGImportExportPlugin::exportFile()
 {
     SKGError err;
@@ -656,16 +720,23 @@ void SKGImportExportPlugin::mergeImportedOperation()
             SKGOperationObject opManual(selection.at(1));
             if (opImported.isImported() != opManual.isImported()) {
                 if (!opImported.isImported())  qSwap(opImported, opManual);
-                int rc = KMessageBox::Yes;
-                if (opImported.getCurrentAmount() != opManual.getCurrentAmount()) {
-                    rc = KMessageBox::questionYesNo(SKGMainPanel::getMainPanel(),
-                                                    i18nc("Question",  "Amounts are not equals. Do you want to force the merge ?"),
-                                                    i18nc("Question",  "Do you want to force the merge ?"),
-                                                    KStandardGuiItem::yes(), KStandardGuiItem::no()
-                                                   );
-                }
 
-                if (rc == KMessageBox::Yes) {
+                //Mode force?
+                bool modeForce = false;
+                QAction* act = qobject_cast< QAction* >(sender());
+                if (act) modeForce = (act->data().toInt() == 1);
+
+                if (!modeForce && opImported.getCurrentAmount() != opManual.getCurrentAmount()) {
+                    KMessageWidget* msgWidget = SKGMainPanel::getMainPanel()->displayErrorMessage(i18nc("Question",  "Amounts are not equals. Do you want to force the merge ?"));
+                    QAction* force = new QAction(i18nc("Noun", "Force the merge"), msgWidget);
+                    force->setIcon(KIcon("run-build"));
+                    force->setData(1);
+                    msgWidget->addAction(force);
+                    connect(force, SIGNAL(triggered(bool)), this, SLOT(mergeImportedOperation()));
+                    connect(force, SIGNAL(triggered(bool)), msgWidget, SLOT(deleteLater()), Qt::QueuedConnection);
+
+                    err = SKGError();
+                } else {
                     SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Merge imported operations"), err);
                     err = opManual.mergeAttribute(opImported);
                     if (err) err.addError(ERR_FAIL, i18nc("Error message", "Merge failed"));
@@ -736,7 +807,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
 
     //Krunner operations
     QString dirName = QDir::homePath() % "/.skrooge/";
-    QStringList fileList = QDir(dirName).entryList(QDir::Files);
+    QStringList fileList = QDir(dirName).entryList(QStringList() << "add_operation_*.txt", QDir::Files);
     int nb = fileList.count();
     if (nb) {
         QStringList listAccounts;
@@ -842,7 +913,7 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                     imp1.setAutomaticValidation(automatic_validation);
                     imp1.setAutomaticApplyRules(automatic_rule);
                     imp1.setSinceLastImportDate(since_last);
-                    err = imp1.finalizedImportedOperations();
+                    err = imp1.finalizeImportation();
                 }
 
                 //Close file
