@@ -150,7 +150,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     //------------
     m_openDuplicate = new KAction(KIcon("skrooge_duplicate", NULL, overlayopen), i18nc("Verb", "Open potential duplicates..."), this);
     m_openDuplicate->setData(QString("skg://skrooge_operation_plugin/?title_icon=skrooge_duplicate&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations potentially duplicated")) %
-                                     "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT o1.id FROM v_operation o1 WHERE EXISTS (SELECT 1 FROM v_operation o2 WHERE o1.id<>o2.id AND o1.t_template='N' AND o2.t_template='N' AND o1.d_date=o2.d_date  AND o1.f_CURRENTAMOUNT=o2.f_CURRENTAMOUNT AND o1.rd_account_id=o2.rd_account_id AND o1.rc_unit_id=o2.rc_unit_id AND (o1.t_status='N' OR o2.t_status='N')))")));
+                                     "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT o1.id FROM v_operation o1 WHERE EXISTS (SELECT 1 FROM v_operation o2 WHERE o1.id<>o2.id AND o1.t_template='N' AND o2.t_template='N' AND o1.d_date=o2.d_date  AND ABS(o1.f_CURRENTAMOUNT-o2.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % " AND o1.rd_account_id=o2.rd_account_id AND o1.rc_unit_id=o2.rc_unit_id AND (o1.t_status='N' OR o2.t_status='N')))")));
     connect(m_openDuplicate, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
     m_openDuplicate->setShortcut(Qt::META + Qt::Key_D);
     registerGlobalAction("view_open_duplicates", m_openDuplicate);
