@@ -34,15 +34,25 @@
 #include <QDomDocument>
 
 SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
-    : SKGWidget(iDocument)
+    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Alarms"))
 {
     SKGTRACEIN(10, "SKGAlarmBoardWidget::SKGAlarmBoardWidget");
 
-    ui.setupUi(this);
+    //Create widget
+    m_frame = new QFrame();
+    m_layout = new QVBoxLayout(m_frame);
+    m_layout->setSpacing(2);
+    m_layout->setContentsMargins(0, 0, 0, 0);
+    setMainWidget(m_frame);
 
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
+    KAction* open = new KAction(KIcon("skg_open"), i18nc("Verb, open a page", "Open..."), this);
+    open->setData("skg://skrooge_search_plugin");
+    connect(open, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+    addAction(open);
+
     m_menuFavorite = new KAction(KIcon("bookmarks"), i18nc("Noun, an option in contextual menu", "Highlighted only"), this);
     m_menuFavorite->setCheckable(true);
     m_menuFavorite->setChecked(false);
@@ -89,7 +99,7 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
     if (iTableName == "operation" || iTableName == "rule" || iTableName.isEmpty()) {
         //Remove all item of the layout
         QLayoutItem* child = NULL;
-        while ((child = ui.layout->takeAt(0)) != 0) {
+        while ((child = m_layout->takeAt(0)) != 0) {
             QWidget* w = child->widget();
             delete w;
             delete child;
@@ -112,11 +122,11 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
             int nb = rules.count();
             if (nb) {
                 for (int i = 0; !err && i < nb; ++i) {
-                    SKGRuleObject rule = rules.at(i);
+                    SKGRuleObject rule(rules.at(i));
                     SKGRuleObject::SKGAlarmInfo alarm = rule.getAlarmInfo();
 
                     //Create progress bar
-                    SKGProgressBar* progressBar = new SKGProgressBar(ui.kGroup);
+                    SKGProgressBar* progressBar = new SKGProgressBar(m_frame);
                     progressBar->setObjectName(QString::fromUtf8("progressBar"));
                     progressBar->setMaximum(qMax(alarm.Amount, alarm.Limit));
                     progressBar->setValue(alarm.Amount);
@@ -139,21 +149,18 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                     progressBar->setLimits(qMax(alarm.Amount, alarm.Limit), 0.9 * alarm.Limit, 0.7 * alarm.Limit);
 
                     //Add progress bar
-                    ui.layout->addWidget(progressBar);
+                    m_layout->addWidget(progressBar);
                 }
             } else {
-                QLabel* lab = new QLabel(ui.kGroup);
+                QLabel* lab = new QLabel(m_frame);
                 lab->setTextInteractionFlags(Qt::LinksAccessibleByMouse | Qt::TextSelectableByMouse);
-                lab->setText(i18nc("Message", "No alarm defined<br>on the <a href=\"skg://Skrooge_search_plugin\">\"Search and process\"</a> page."));
+                lab->setText(i18nc("Message", "No alarm defined<br>on the <a href=\"%1\">\"Search and process\"</a> page.", "skg://Skrooge_search_plugin"));
                 connect(lab, SIGNAL(linkActivated(QString)), SKGMainPanel::getMainPanel(), SLOT(openPage(QString)));
 
                 //Add progress bar
-                ui.layout->addWidget(lab);
+                m_layout->addWidget(lab);
             }
 
-            //Add spacer
-            ui.layout->addItem(new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding));
-
             //No widget if no account
             bool exist = false;
             getDocument()->existObjects("account", "", exist);
@@ -162,13 +169,4 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
     }
 }
 
-void SKGAlarmBoardWidget::onOpen(const QString& iLink)
-{
-    ui.kGroup->setChecked(true);
-
-    if (iLink == "___") {
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge search plugin"));
-    }
-}
-
 #include "skgalarmboardwidget.moc"
