@@ -21,15 +21,16 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "ui_skgalarmboardwidget_board.h"
-#include "skgwidget.h"
+#include "skgboardwidget.h"
 
+class QVBoxLayout;
+class QFrame;
 class KAction;
 
 /**
  * This file is Skrooge dashbord plugin for alarms
  */
-class SKGAlarmBoardWidget : public SKGWidget
+class SKGAlarmBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
 
@@ -61,14 +62,12 @@ public:
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName = "", int iIdTransaction = 0);
-    void onOpen(const QString& iLink = "___");
 
 private:
-    Q_DISABLE_COPY(SKGAlarmBoardWidget);
-
-    Ui::skgalarmplugin_board ui;
-
+    Q_DISABLE_COPY(SKGAlarmBoardWidget)
     KAction* m_menuFavorite;
+    QFrame* m_frame;
+    QVBoxLayout* m_layout;
 };
 
 #endif // SKGALARMBOARDWIDGET_H
