@@ -34,7 +34,7 @@ class SKGSearchPluginWidget : public SKGTabPage
     /**
      * This enumerate defines the open mode
      */
-    Q_ENUMS(OpenMode);
+    Q_ENUMS(OpenMode)
 public:
     /**
      * This enumerate defines the open mode
@@ -135,7 +135,7 @@ private Q_SLOTS:
     void cleanEditor();
 
 private:
-    Q_DISABLE_COPY(SKGSearchPluginWidget);
+    Q_DISABLE_COPY(SKGSearchPluginWidget)
 
     QString getXMLActionDefinition();
     Ui::skgsearchplugin_base ui;
