@@ -80,7 +80,7 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     //-----------
     KAction* act = new KAction(KIcon(icon()), i18nc("Verb", "Delete unused units"), this);
     connect(act, SIGNAL(triggered(bool)), this, SLOT(deleteUnusedUnits()));
-    registerGlobalAction("tool_delete_unused_units", act);
+    registerGlobalAction("clean_delete_unused_units", act);
     return true;
 }
 
@@ -101,7 +101,7 @@ SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 0) return new SKGUnitBoardWidget(m_currentBankDocument);
     else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
                                      getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/portfolio.html"),
+                                     KStandardDirs().findResource("data", "skrooge/html/default/portfolio.html"),
                                      QStringList() << "v_operation_display");
     return NULL;
 }
@@ -348,7 +348,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused units"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no operation is registered."));
             QStringList autoCorrections;
-            autoCorrections.push_back("skg://tool_delete_unused_units");
+            autoCorrections.push_back("skg://clean_delete_unused_units");
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
