@@ -121,7 +121,7 @@ protected:
 
 
 private:
-    Q_DISABLE_COPY(SKGDataEngine);
+    Q_DISABLE_COPY(SKGDataEngine)
 
     /**
      * The document used to retrieve data
