@@ -63,7 +63,7 @@ SKGUnitObject SKGUnitComboBox::getUnit()
             if (!err) err = unitVal.setQuantity(1);
             if (!err) err = unitVal.save();
 
-            if (!err) m_document->sendMessage(i18nc("An information message",  "Unit '%1' has been created" , text()), true);
+            if (!err) m_document->sendMessage(i18nc("An information message",  "Unit '%1' has been created" , text()), SKGDocument::Positive);
         } else err = unit.load();
     }
     return unit;
