@@ -152,7 +152,6 @@ SKGError SKGBudgetObject::process()
     //Main values
     int m = getMonth();
     int y = getYear();
-    double budgeted = getBudgetedAmount();
     double transferred = SKGServices::stringToDouble(getAttribute("f_transferred"));
 
     //Get budgets rules ordered
@@ -176,7 +175,7 @@ SKGError SKGBudgetObject::process()
             if (delta) {
                 if (cond == SKGBudgetRuleObject::ALL || (delta < 0 && cond == SKGBudgetRuleObject::NEGATIVE) || (delta > 0 && cond == SKGBudgetRuleObject::POSITIVE)) {
                     //Compute value to transfer
-                    double value = (rule.isAbolute() ? (cond == SKGBudgetRuleObject::NEGATIVE ? qMax(delta, quantity) : qMin(delta, quantity)) : quantity * delta / 100.0);
+                    double value = (rule.isAbolute() ? (cond == SKGBudgetRuleObject::NEGATIVE ? qMax(delta, quantity) : qMin(delta, quantity)) : quantity * (delta - transferred) / 100.0);
 
                     //Get impacted budget
                     SKGBudgetObject impactedBudget = *this;
@@ -185,19 +184,21 @@ SKGError SKGBudgetObject::process()
                     SKGBudgetRuleObject::Mode mode = rule.getTransferMode();
                     if (mode == SKGBudgetRuleObject::NEXT) {
                         //Next
-                        if (m == 0) {
+                        int mi = m;
+                        int yi = y;
+                        if (mi == 0) {
                             //Yearly budget
-                            ++y;
+                            ++yi;
                         } else {
                             //Monthly budget
-                            ++m;
-                            if (m == 13) {
-                                m = 1;
-                                ++y;
+                            ++mi;
+                            if (mi == 13) {
+                                mi = 1;
+                                ++yi;
                             }
                         }
-                        if (!err) err = impactedBudget.setYear(y);
-                        if (!err) err = impactedBudget.setMonth(m);
+                        if (!err) err = impactedBudget.setYear(yi);
+                        if (!err) err = impactedBudget.setMonth(mi);
                     } else if (mode == SKGBudgetRuleObject::YEAR) {
                         //Year
                         if (!err) err = impactedBudget.setYear(y);
@@ -214,9 +215,10 @@ SKGError SKGBudgetObject::process()
                     if (!err) {
                         if (impactedBudget.exist()) {
                             err = impactedBudget.load();
-                            QString newBudget = SKGServices::doubleToString(budgeted - value);
+                            QString newBudget = SKGServices::doubleToString(impactedBudget.getBudgetedModifiedAmount() - value);
                             if (!err) err = impactedBudget.setAttribute("f_budgeted_modified", newBudget);
                             if (!err) err = impactedBudget.save();
+                            SKGTRACEL(1) << "Transfer " << value << " from '" << getDisplayName() << "' to '" << impactedBudget.getDisplayName() << "' due to '" << rule.getDisplayName() << "'" << endl;
 
                             transferred += value;
                             if (!err) err = setAttribute("f_transferred", SKGServices::doubleToString(transferred));
@@ -239,6 +241,7 @@ SKGError SKGBudgetObject::process()
 
 SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int iYear, int iBaseYear, bool iUseScheduledOperation, bool iRemovePreviousBudget)
 {
+    Q_UNUSED(iUseScheduledOperation);
     SKGError err;
     SKGTRACEINRC(10, "SKGBudgetObject::createAutomaticBudget", err);
     QString baseYear = SKGServices::intToString(iBaseYear);
