@@ -34,8 +34,8 @@ class SKGUnitValueObject;
  */
 class SKGBANKMODELER_EXPORT SKGDocumentBank : public SKGDocument
 {
-    Q_OBJECT;
-    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGDocumentBank");
+    Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGDocumentBank")
 
 public:
     /**
@@ -222,17 +222,17 @@ protected:
     virtual SKGError computeBalances();
 
     /**
-     * Compute the budgets categories links.
+     * Compute the budget suboperation links.
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError computeBudgetCategoriesLinks();
+    virtual SKGError computeBudgetSuboperationLinks();
 
 private Q_SLOTS:
     virtual void refreshCache(const QString& iTable);
 
 private:
-    Q_DISABLE_COPY(SKGDocumentBank);
+    Q_DISABLE_COPY(SKGDocumentBank)
 
     QString m_5mainVariations_inputs;
     QStringList m_5mainVariations_cache;
