@@ -121,9 +121,9 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
 
         //Searching if an account exist
         QString whereClause = "t_name='" % name % '\'';
+        if (!number.isEmpty()) whereClause += " OR t_number='" % number % "'";
         foreach(const QString & val, name.split(' ')) {
-            if (!whereClause.isEmpty()) whereClause += " OR ";
-            whereClause += "t_number='" % val % "'";
+            whereClause += " OR t_number='" % val % "'";
         }
         if (!whereClause.isEmpty()) {
             SKGObjectBase::SKGListSKGObjectBase listAccount;
@@ -256,13 +256,13 @@ bool SKGImportExportManager::sinceLastImportDate() const
     return m_since_last_import;
 }
 
-SKGError SKGImportExportManager::finalizedImportedOperations()
+SKGError SKGImportExportManager::finalizeImportation()
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations", err);
-    if (m_document) {
+    SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation", err);
+    if (m_document && !getImportParameters().contains("donotfinalize")) {
         //Count the number of operations imported but already existing
-        QString wc = "t_imported='T' AND v_operation.t_import_id<>'' AND exists (SELECT 1 from v_operation op2 WHERE op2.id!=v_operation.id AND op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND op2.f_CURRENTAMOUNT=v_operation.f_CURRENTAMOUNT)";
+        QString wc = "v_operation.t_imported='T' AND v_operation.t_import_id<>'' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % ')';
         int nb;
         err = m_document->getNbObjects("v_operation", wc, nb);
         if (!err && nb) {
@@ -274,7 +274,7 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
 
         //Delete operations before the last import
         if (m_since_last_import && !err) {
-            SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations-deletebeforelastimport", err);
+            SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-deletebeforelastimport", err);
             err = m_document->executeSqliteOrder("DELETE FROM operation WHERE operation.t_imported='T' AND "
                                                  "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>=operation.d_date)");
         }
@@ -284,7 +284,7 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
 
         //Apply rules
         if (!err && m_automaticApplyRulesOfImportedOperation) {
-            SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations-applyrules", err);
+            SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-applyrules", err);
             //Get rules
             SKGObjectBase::SKGListSKGObjectBase rules;
             err = m_document->getObjects("v_rule", "1=1 ORDER BY f_sortorder", rules);
@@ -306,7 +306,7 @@ SKGError SKGImportExportManager::finalizedImportedOperations()
 
         //Change imported status
         if (!err) {
-            SKGTRACEINRC(2, "SKGImportExportManager::finalizedImportedOperations-setfinalstatus", err);
+            SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-setfinalstatus", err);
             err = m_document->executeSqliteOrder(QString("UPDATE operation SET t_imported='") %
                                                  (m_automaticValidationOfImportedOperation ? "Y" : "P") %
                                                  "' WHERE t_imported='T'");
@@ -486,7 +486,7 @@ SKGError SKGImportExportManager::importFile()
         }
         if (!err) err = m_document->stepForward(2);
 
-        if (!err) err = finalizedImportedOperations();
+        if (!err) err = finalizeImportation();
         if (!err) err = m_document->stepForward(3);
     }
 
@@ -670,7 +670,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged)
             SKGStringListList listTmp;
             //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
             err = m_document->executeSelectSqliteOrder(
-                      "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND A.f_QUANTITY=-B.f_QUANTITY AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0",
+                      "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_QUANTITY+B.f_QUANTITY)<" % SKGServices::doubleToString(EPSILON) % " AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0",
                       listTmp);
             //Step 1 done
             if (!err) err = m_document->stepForward(1);
@@ -678,7 +678,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged)
             SKGStringListList listTmp2;
             //+A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
             if (!err) err = m_document->executeSelectSqliteOrder(
-                                    "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND A.f_CURRENTAMOUNT=-P.t_value AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0",
+                                    "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0",
                                     listTmp2);
 
             //Step 2 done
