@@ -34,7 +34,7 @@ class SKGDocumentBank;
  */
 class SKGBANKMODELER_EXPORT SKGImportPlugin : public KParts::Plugin
 {
-    Q_OBJECT ;
+    Q_OBJECT
 public:
 
     /**
@@ -107,7 +107,7 @@ public:
     }
 
 private:
-    Q_DISABLE_COPY(SKGImportPlugin);
+    Q_DISABLE_COPY(SKGImportPlugin)
 
 protected:
     SKGImportExportManager* m_importer;
@@ -117,6 +117,6 @@ protected:
 /**
  * This plugin interface definition.
  */
-Q_DECLARE_INTERFACE(SKGImportPlugin, "skrooge.com.SKGImportPlugin/1.0");
+Q_DECLARE_INTERFACE(SKGImportPlugin, "skrooge.com.SKGImportPlugin/1.0")
 
 #endif // SKGIMPORTPLUGIN_H
