@@ -340,6 +340,11 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
     else if (output == "#ATT#=WORD(#ATT2#,#V1S#)")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#)").replace("#ATT2#", iAtt2).replace("#V1S#", iParam1);
 
+    else if (output == "#ATT#=todate(#ATT2#,'#DF#')")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=#ATT2# as date with format #DF#").replace("#ATT2#", iAtt2).replace("#DF#", iParam2);
+    else if (output == "#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')")
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "=word(#ATT2#,#V1S#) as date with format #DF#").replace("#ATT2#", iAtt2).replace("#V1S#", iParam1).replace("#DF#", iParam2);
+
     else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now'))")
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in current month");
     else if (output == "STRFTIME('%Y-%m',#ATT#)=STRFTIME('%Y-%m',date('now','start of month','-1 month'))")
@@ -384,8 +389,10 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
         } else if (iAttributeType == SKGServices::DATE || iAttributeType == SKGServices::BOOL || iAttributeType == SKGServices::TRISTATE) {
             output.push_back("#ATT#='#V1S#'");
         }
-
-        if (iAttributeType != SKGServices::BOOL && iAttributeType != SKGServices::TRISTATE) {
+        if (iAttributeType == SKGServices::DATE) {
+            output.push_back("#ATT#=todate(#ATT2#,'#DF#')");
+            output.push_back("#ATT#=todate(WORD(#ATT2#,#V1S#),'#DF#')");
+        } else if (iAttributeType != SKGServices::BOOL && iAttributeType != SKGServices::TRISTATE) {
             output.push_back("#ATT#=substr(#ATT2#,'#V1#','#V2#')");
             output.push_back("#ATT#=#ATT2#");
             output.push_back("#ATT#=WORD(#ATT2#,#V1S#)");
@@ -497,6 +504,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                         part = part.replace("#V1S#", SKGServices::stringToSqlString(element.attribute("value")));
                         part = part.replace("#V2#", SKGServices::stringToSqlString(element.attribute("value2")));
                         part = part.replace("#V2S#", SKGServices::stringToSqlString(element.attribute("value2")));
+                        part = part.replace("#DF#", SKGServices::stringToSqlString(element.attribute("value2")));
                         part = part.replace("#OP#", SKGServices::stringToSqlString(element.attribute("operator2")));
 
                         elementDescription += part;
