@@ -810,12 +810,14 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
+        QModelIndex parentIndex = parent;
         SKGNodeObject parentNode;
-        if (parent.isValid()) {
-            parentNode = getObject(parent);
+        if (parentIndex.isValid()) {
+            parentNode = getObject(parentIndex);
             if (!parentNode.isFolder()) {
                 //The parent is not a directory
                 parentNode.getParentNode(parentNode);
+                parentIndex = parentIndex.parent();
             }
         }
         {
@@ -824,14 +826,14 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
             double min = 0;
             double max = 0;
             if (row >= 1) {
-                QModelIndex previousIndex = SKGObjectModelBase::index(row - 1, 0, parent);
+                QModelIndex previousIndex = SKGObjectModelBase::index(row - 1, 0, parentIndex);
                 SKGNodeObject previousObject(getObject(previousIndex));
                 min = previousObject.getOrder();
             }
 
-            if (row >= rowCount(parent)) max = min + 1;
+            if (row >= rowCount(parentIndex)) max = min + 1;
             else {
-                QModelIndex nextIndex = SKGObjectModelBase::index(row, 0, parent);
+                QModelIndex nextIndex = SKGObjectModelBase::index(row, 0, parentIndex);
                 SKGNodeObject nextObject(getObject(nextIndex));
                 max = nextObject.getOrder();
             }
@@ -847,7 +849,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* data,
                 SKGNodeObject child(getDocument(), o_id);
                 err = child.load();
                 if (!err) {
-                    if (parent.isValid()) err = child.setParentNode(parentNode);
+                    if (parentIndex.isValid()) err = child.setParentNode(parentNode);
                     else err = child.removeParentNode();
                 }
 
@@ -875,7 +877,7 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
         SKGTRACEL(1) << "getTable=" << getRealTable() << endl;
         SKGTRACEL(1) << "Parameters=" << iTableName << " , " << iIdTransaction << endl;
         SKGTabPage* page = SKGTabPage::parentTabPage(qobject_cast< QWidget* >(this->QObject::parent()));
-        SKGTabPage* cpage = SKGMainPanel::getMainPanel()->currentPage();
+        SKGTabPage* cpage = SKGMainPanel::getMainPanel() ? SKGMainPanel::getMainPanel()->currentPage() : NULL;
         if (page != NULL && page != cpage) {
             m_isResetRealyNeeded = true;
             return;
