@@ -484,7 +484,7 @@ void SKGTreeView::setupHeaderMenu()
 
                     //Group by menu
                     QString att = m_model->getAttribute(idx);
-                    if (act->isChecked() && groupbymenu && groupby) {
+                    if (groupbymenu && groupby) {
                         QAction* act2 = groupbymenu->addAction(values.at(0));
                         if (act2) {
                             act2->setCheckable(true);
@@ -598,11 +598,7 @@ void SKGTreeView::showHideColumn()
         m_model->setSupportedAttributes(getCurrentSchema());
         if (!hidden) resizeColumnToContents(idx);
 
-        //If the group by attibute is hidden the the group is removed
-        QString att = m_model->getAttribute(idx);
-        QString groupBy = m_model->getGroupBy();
-        if (hidden &&  att == groupBy) groupByChanged(m_actGroupByNone);
-        else m_model->dataModified();
+        m_model->dataModified();
     }
 }
 
