@@ -123,7 +123,7 @@ protected:
     virtual bool eventFilter(QObject* object, QEvent* event);
 
 private:
-    Q_DISABLE_COPY(SKGWebView);
+    Q_DISABLE_COPY(SKGWebView)
 };
 
 #endif
