@@ -50,6 +50,11 @@ class SKGBASEMODELER_EXPORT SKGDocument : public QObject
      */
     Q_ENUMS(ModificationType)
 
+    /**
+     * This enumerate defines a type of message
+     */
+    Q_ENUMS(MessageType)
+
     /**
      * This enumerate defines the direction of the UNDO / REDO mechanism
      */
@@ -89,6 +94,17 @@ public:
         D  /**< Delete */
     };
 
+    /**
+     * This enumerate defines a type of message
+     */
+    enum MessageType {
+        Positive,     /**< Positive */
+        Information,  /**< Information */
+        Warning,      /**< Warning */
+        Error,        /**< Error */
+        Hidden        /**< Hidden */
+    };
+
     /**
      * Describe a modification of an object
      */
@@ -213,21 +229,22 @@ public Q_SLOTS:
     /**
      * Send a message attached to the current transaction.
      * @param iMessage the message
-     * @param iPopup to create a popup message
+     * @param iMessageType the message type
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError sendMessage(const QString& iMessage, bool iPopup = true);
+    virtual SKGError sendMessage(const QString& iMessage, MessageType iMessageType = SKGDocument::Information);
 
     /**
      * Get message attached to a transaction.
      * @param iIdTransaction the identifier of a transaction
      * @param oMessages the messages
-     * @param iAll to get all message (true) or only popup message (false)
+     * @param oMessageTypes the types of messages
+     * @param iAll to get all message (true) or only non hidden messages (false)
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getMessages(int iIdTransaction, QStringList& oMessages, bool iAll = true);
+    virtual SKGError getMessages(int iIdTransaction, QStringList& oMessages, QList<MessageType>& oMessageTypes, bool iAll = true);
 
     /**
      * Remove all message attached to a transaction.
@@ -887,6 +904,7 @@ private:
     QString m_temporaryFile;
     QString m_uniqueIdentifier;
     QStringList m_unTransactionnalMessages;
+    QList<MessageType> m_unTransactionnalMessagesTypes;
     QMap<QString, QStringList> m_ImpactedViews;
     QMap<QString, QStringList> m_MaterializedViews;
 
