@@ -34,28 +34,28 @@
 */
 class SKGBASEMODELER_EXPORT SKGError : public QObject
 {
-    Q_OBJECT;
-    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGError");
+    Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.skrooge.SKGError")
     /**
      * Return code of the error
      */
-    Q_PROPERTY(int returnCode READ getReturnCode WRITE setReturnCode);
+    Q_PROPERTY(int returnCode READ getReturnCode WRITE setReturnCode)
     /**
      * Message of the error
      */
-    Q_PROPERTY(QString message READ getMessage WRITE setMessage);
+    Q_PROPERTY(QString message READ getMessage WRITE setMessage)
     /**
      * Full message of the error
      */
-    Q_PROPERTY(QString message READ getFullMessageWithHistorical);
+    Q_PROPERTY(QString message READ getFullMessageWithHistorical)
     /**
      * To know if it is a success of the error
      */
-    Q_PROPERTY(bool succeeded READ isSucceeded);
+    Q_PROPERTY(bool succeeded READ isSucceeded)
     /**
      * To know if it is a failure of the error
      */
-    Q_PROPERTY(bool failed READ isFailed);
+    Q_PROPERTY(bool failed READ isFailed)
 public:
     /**
     * Constructor
@@ -214,12 +214,12 @@ Q_DECLARE_TYPEINFO(SKGError, Q_MOVABLE_TYPE);
 /**
  * Declare the meta type
  */
-Q_DECLARE_METATYPE(SKGError);
+Q_DECLARE_METATYPE(SKGError)
 
 /**
  * Declare the meta type
  */
-Q_DECLARE_METATYPE(SKGError*);
+Q_DECLARE_METATYPE(SKGError*)
 
 /**
 * Function for scription
