@@ -193,14 +193,14 @@ public:
      * @param iNumber the integer to convert
      * @return the converted QString
      */
-    static QString intToString(int iNumber);
+    static QString intToString(qlonglong iNumber);
 
     /**
      * Convert a QString into an integer
      * @param iNumber the QString to convert
      * @return the converted integer
      */
-    static int stringToInt(const QString& iNumber);
+    static qlonglong stringToInt(const QString& iNumber);
 
     /**
      * Convert a QString into a csv QString
